import org.w3c.dom.*;
import javax.xml.parsers.*;
import javax.xml.transform.*;
import javax.xml.transform.dom.*;
import javax.xml.transform.stream.*;
import java.io.*;
import java.util.*;

public class SSDOM
{
  public void save(String fileName)
  {
    try
    {
      DocumentBuilderFactory factory = DocumentBuilderFactory.newInstance();
      DocumentBuilder builder = factory.newDocumentBuilder();
      Document doc = builder.newDocument();
      Element e = doc.createElement("solar-system");
      e.setAttribute("timestamp", "" + new Date().getTime());
      doc.appendChild(e);
      for (Planet p : Planet.values())
      {
        Element planet = doc.createElement("planet");
        planet.setAttribute("name", p.getName());
        planet.setAttribute("degree", "" + p.getAngle());
        e.appendChild(planet);
      }
      // SAVE
      DOMSource source = new DOMSource(doc);
      // file outputStream  semplicemente il "file", mentre StreamResult
      //  di DOM
      StreamResult result = new StreamResult(new
                                             FileOutputStream(fileName));
      // eventuali regole di traduzione parametro del traduttore
      Transformer t = TransformerFactory.newInstance().newTransformer();
      t.setOutputProperty(OutputKeys.DOCTYPE_SYSTEM,"solarsystem.dtd");
      t.transform(source, result);
    }
    catch (Exception ex)
    {
      ex.printStackTrace();
    }
  }

  public void load(String fileName)
  {
    try
    {
      DocumentBuilderFactory factory = DocumentBuilderFactory.newInstance();
      factory.setValidating(true);
      DocumentBuilder builder = factory.newDocumentBuilder();
      Document doc = builder.parse(new File(fileName));

      Element e = doc.getDocumentElement();
      NodeList planets = e.getChildNodes();
      for (int i = 0; i < planets.getLength(); i++)
      {
        Element planet = (Element)planets.item(i);
        for (Planet p : Planet.values())
          if (p.getName().equals(planet.getAttribute("name")) &&
              planet.hasAttribute("degree"))
            p.setAngle(Double.parseDouble(planet.getAttribute("degree")));
      }
    }
    catch (Exception ex)
    {
      ex.printStackTrace();
    }
  }


  /*public static void main(String[] args)
  {
    SSDOM doc = new SSDOM();
    Planet.stop();
    Planet.EARTH.setAngle(54);
    doc.save("pippo.xml");
    Planet.EARTH.setAngle(8);
    System.out.println(Planet.EARTH.getAngle());
    doc.load("pippo.xml");
    System.out.println(Planet.EARTH.getAngle());
  }*/

}
